/**
 * @package xbeemicrolib
 * @filename main.c
 * 
 * @author ysuga (ysuga.net)
 * @license public domain
 */

#ifdef __USE_CMSIS
#include "LPC11xx.h"
#endif

#include "color_led.h"
#include "systick.h"
#include "xbeemicrolib_mary/xbeemicrolib.h"

/*
 * Receive Event Handler
 *
 * in main function. this function is registered in xbeemicrolib framework by calling xbee_registerOnRxPacket
 */
void myOnRxPacket(const char* addr64, const char* addr16, const char* dat, const unsigned short size)
{
	/**
	 * Switch by first byte
	 */
	switch(dat[0]) {
	case 'r':
		Set_Color_LED(0x01);
		break;
	case 'g':
		Set_Color_LED(0x02);
		break;
	case 'b':
		Set_Color_LED(0x04);
		break;
	default:
		Set_Color_LED(0);
	}
}


/**
 * Host Record
 */
XBeeHostRecord coordinator = HOST_RECORD_COORDINATOR;


//-----------------------
// Main Routine
//-----------------------
int main(void)
{
    //
    // Initialization
    //
    Init_SysTick();
    Init_Color_LED();

	/**
	 * Setup Xbee. Parameters of the network is configured in this function.
	 * Parameters can be changed by you in "xbee_conf.h" file.
	 */
	XBee_setup();

	/**
	 * This function register the receive event handler.
	 */
	XBee_registerOnRxPacket(myOnRxPacket);

	/* Loop */
	while(1) {
		/**
		 * this function must be called periodically.
		 */
		XBee_polling();
	}
	return 0;

}

//=========================================================
// End of Program
//=========================================================
