/**
 * @package xbeemicrolib
 * @filename xbee_uart.c
 * 
 * @author ysuga (ysuga.net)
 * @copyright ysuga.net 2011 allrights reserved
 * @license GPL
 */

#include "LPC11xx.h"
#include "../type.h"
#include "../uart.h"

#include "xbee_uart.h"


int uart_block = 0;



/**
 * @brief UART Initialization
 */
void uart_setup()
{
	UARTInit(9600);
}

/**
 * @brief Set Blocking Policy
 *
 * @param policy TRUE: block when receive buffer is not empty. FALSE: non-block.
 */
void uart_setBlockingPolicy(int policy) {
	uart_block = policy;
}


/**
 * @brief check receive buffer.
 *
 * @return more than zero if buffer is not empty.
 */
int uart_isReceived() {
	return UARTReceive_Check();
}

/**
 * @brief send 1 byte
 *
 * @param c data packet
 */
void uart_putc(char c)
{
	UARTSend_Byte(c);
}

/**
 * @brief receive 1 byte. blocking behavior is defined by setBlockingPolicy function.
 *
 * @param c receive buffer.
 * @return zero if success. if non-block mode, negative if buffer is empty.
 */
int uart_getc(char* c) {
	if(uart_block) {
		while(!uart_isReceived()) {
		}
	} else {
		if(!uart_isReceived()) {
			return -1;
		}
	}
	*c = UARTReceive_Byte();
	return 0;
}

