/**
 * @package xbeemicrolib
 * @filename xbee_uart.h
 * 
 * @author ysuga (ysuga.net)
 * @copyright ysuga.net 2011 allrights reserved
 * @license GPL
 */

#ifndef UART_HEADER_INCLUDED
#define UART_HEADER_INCLUDED

#ifdef __cplusplus
extern "C" {
#endif

#ifndef TRUE
#define TRUE 1
#endif

#ifndef FALSE
#define FALSE 0
#endif


#define UART_BLOCKING_POLICY_BLOCK TRUE
#define UART_BLOCKING_POLICY_NONBLOCK FALSE

/**
 * @brief UART Initialization
 */
void uart_setup();

/**
 * @brief Set Blocking Policy
 *
 * @param policy TRUE: block when receive buffer is not empty. FALSE: non-block.
 */
void uart_setBlockingPolicy(int policy);

/**
 * @brief send 1 byte
 *
 * @param c data packet
 */
void uart_putc(char c);

/**
 * @brief receive 1 byte. blocking behavior is defined by setBlockingPolicy function.
 *
 * @param c receive buffer.
 * @return zero if success. if non-block mode, negative if buffer is empty.
 */
int uart_getc(char* c);

/**
 * @brief check receive buffer.
 *
 * @return more than zero if buffer is not empty.
 */
int uart_isReceived();


#ifdef __cplusplus
}
#endif


#endif // UART_HEADER_INCLUDED
